@@ -7,10 +7,11 @@ use Carp ();
 use FFI::Temp;
 use File::Basename ();
 use FFI::Build::Platform;
+use FFI::Build::PluginData;
 use overload '""' => sub { $_[0]->path }, bool => sub { 1 }, fallback => 1;
 
 # ABSTRACT: Base class for File::Build files
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 
 sub new
@@ -158,7 +159,7 @@ FFI::Build::File::Base - Base class for File::Build files
 
 =head1 VERSION
 
-version 1.56
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -180,7 +181,7 @@ Use it:
 
 =head1 DESCRIPTION
 
-This class is the base class for other L<FFI::Build::File> classes.
+This class is the base class for other C<FFI::Build::File::*> classes.
 
 =head1 CONSTRUCTOR
 
@@ -357,7 +358,7 @@ Pete Houston (openstrike, HOUSTON)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
+This software is copyright (c) 2015-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
