@@ -7,12 +7,12 @@ use FFI::Platypus;
 use Exporter qw( import );
 
 # ABSTRACT: Memory functions for FFI
-our $VERSION = '1.56'; # VERSION
+our $VERSION = '2.05'; # VERSION
 
 
 our @EXPORT = qw( malloc free calloc realloc memcpy memset strdup strndup strcpy );
 
-my $ffi = FFI::Platypus->new( api => 1 );
+my $ffi = FFI::Platypus->new( api => 2 );
 $ffi->lib(undef);
 $ffi->bundle;
 sub _ffi { $ffi }
@@ -80,7 +80,7 @@ FFI::Platypus::Memory - Memory functions for FFI
 
 =head1 VERSION
 
-version 1.56
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,32 @@ the standard C library.  They may be useful when constructing interfaces
 to C libraries with FFI.  It works mostly with the C<opaque> type and it
 is worth reviewing the section on opaque pointers in L<FFI::Platypus::Type>.
 
+Allocating memory and forgetting to free it is a common source of memory
+leaks in C and when using this module.  Very recent Perls have a C<defer>
+keyword that lets you automatically call functions like C<free> when a
+block ends.  This can be especially handy when you have multiple code
+paths or possible exceptions to keep track of.
+
+ use feature 'defer';
+ use FFI::Platypus::Memory qw( malloc free );
+
+ sub run {
+   my $ptr = malloc 66;
+   defer { free $ptr };
+
+   my $data = do_something($ptr);
+
+   # do not need to remember to place free $ptr here, as it will
+   # run through defer.
+
+   return $data;
+ }
+
+If you are not lucky enough to have the C<defer> feature in your version
+of Perl you may be able to use L<Feature::Compat::Defer>, which will use
+the feature if available, and provides its own mostly compatible version
+if not.
+
 =head1 FUNCTIONS
 
 =head2 calloc
@@ -232,7 +258,7 @@ Pete Houston (openstrike, HOUSTON)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
+This software is copyright (c) 2015-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
